pipelines.chromake.scripts.config.check_config_format

pipelines.chromake.scripts.config.check_config_format(cfg, raise_error=True)

Check the configuration file to make sure it follow the requirements of chromake. At runtile, it will stop snakemake if the file format is invalid.

Parameters

Name Type Description Default
cfg dict A dict object representing a configuration file for the chromake pipeline. required
raise_error bool Raise a runtime error or simply print the message. True