pipelines.chromake.scripts.config.remove_samples

pipelines.chromake.scripts.config.remove_samples(
    config_path,
    sequencing_name,
    samples,
)

Remove specific samples from a project in the YAML config.

Parameters

Name Type Description Default
config_path str Path to the YAML config file. required
sequencing_name str Name of the project containing the samples. required
samples list of str List of sample names to remove. required