genomake
  • Get started
  • Reference
  • Command Line Interface
    • chromake
      • chromake
      • chromake.config
      • chromake.paths

    On this page

    • pipelines.chromake.scripts.paths.get_all_sequencings_related_paths
      • Parameters
      • Returns

    pipelines.chromake.scripts.paths.get_all_sequencings_related_paths

    pipelines.chromake.scripts.paths.get_all_sequencings_related_paths(cfg, mode)

    Get the path to the files generated by the pipeline for the samples of all sequencings and projects.

    Parameters

    Name Type Description Default
    cfg dict Dict representing the configuration of an analysis with the chromake pipeline. required
    mode str String representing the files to get. Accepted values are: - sequencing (raw fastq) - multiqc_raw (multiqc report regrouping the fastqc of the raw fastq files) - cutadapt (fastq after adapter trimming) - fastqc_trimmed (fastqc reports after the adapter trimming) - multiqc_trimmed (multiqc report after adapter trimming) - bam (bam files after alignment with bowtie2) - bam_filtered_coord (bam files after filtering the non-standard chromosomes and sorted by coordinate) - bam_filtered_name (bam files after filtering the non-standard chromosomes and sorted by name) - bedgraph (bedGrapg files generated by HOMER for UCSC visualisation) required

    Returns

    Name Type Description
    list A list of file paths.