pipelines.chromake.scripts.paths.get_project_paths_for_macs

pipelines.chromake.scripts.paths.get_project_paths_for_macs(
    cfg,
    project_name,
    mode,
)

Get the files necessary for the macs2/macs3 rules of a project.

Parameters

Name Type Description Default
cfg dict Dict representing the configuration of an analysis with the chromake pipeline. required
project_name str String representing the name of the project in cfg required
mode str String indicating the output. Accepted values are: - macs (dict with all inputs and the outputs of the macs3 command for all samples associated with the project) - macs_output (list of all outputs of the macs3 command for the project) required

Returns

Name Type Description
A dictionary of all file paths for the project.