genomake
  • Get started
  • Reference
  • Command Line Interface
    • chromake
      • chromake
      • chromake.config
      • chromake.paths

    On this page

    • pipelines.chromake.scripts.paths.get_sequencings_related_paths
      • Parameters
      • Returns

    pipelines.chromake.scripts.paths.get_sequencings_related_paths

    pipelines.chromake.scripts.paths.get_sequencings_related_paths(
        cfg,
        sequencing_name,
        mode,
    )

    Get the path to the files generated by the pipeline for the samples of a specific sequencing.

    Parameters

    Name Type Description Default
    cfg dict Dict representing the configuration of an analysis with the chromake pipeline. required
    sequencing_name str String representing the name of the sequencing required
    mode str String representing the files to get. Accepted values are: - sequencing (raw fastq) - multiqc_raw (multiqc report regrouping the fastqc of the raw fastq files) - cutadapt (fastq after adapter trimming) - fastqc_trimmed (fastqc reports after the adapter trimming) - multiqc_trimmed (multiqc report after adapter trimming) - bam (bam files after alignment with bowtie2) - bam_filtered (bam files after filtering the non-standard chromosomes) - flagstat (output of samtools flagstat on the bam files) - stats (output of samtools stats on the bam files) - multiqc_stats (multiqc on the folder containing the stats output) required

    Returns

    Name Type Description
    list A list of all file paths.