pipelines.chromake.scripts.config.check_project_and_sequencing
pipelines.chromake.scripts.config.check_project_and_sequencing(config)Ensures that projects with no associated sequencing samples are removed from the config, and removes empty sequencing projects, while making sure the mark is considered in the filtering process.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| config | dict | Loaded YAML config (as a dictionary). | required |
Returns
| Name | Type | Description |
|---|---|---|
| dict | Updated config dictionary. |