Create a samplesheet table (CSV or Excel) from a YAML config, resolving relative paths by adding the sequencing project path. Includes both SAMPLES and INPUTS.
Parameters
Name
Type
Description
Default
config_path
str
Path to the YAML config file.
required
output_path
str
Path to save the generated table (CSV by default; Excel if excel=True).
required
strand_columns
bool
If True, each strand (R1, R2) PATH will be a separate column (wide format); if False, each strand will be in separate rows and a STRAND columns will be added to differentiate them (long format).
False
excel
bool
If True, save as Excel (.xlsx). Otherwise, save as CSV.